<?php

namespace App\Entity;

use Doctrine\DBAL\Types\Types;
use JsonSerializable;
use App\Repository\NotesRepository;
use Doctrine\ORM\Mapping as ORM;

#[ORM\Entity(repositoryClass: NotesRepository::class)]
class Notes implements JsonSerializable
{
    #[ORM\Id()]
    #[ORM\Column(type: Types::INTEGER)]
    private ?int $id = null;

    #[ORM\Column(length: 255)]
    private ?string $title = null;

    #[ORM\ManyToOne(inversedBy: 'notes')]
    #[ORM\JoinColumn(nullable: false)]
    private ?Speaker $speaker = null;

    #[ORM\ManyToOne(inversedBy: 'notes')]
    private ?Series $series = null;

    #[ORM\Column(length: 4096)]
    private ?string $text = null;

    #[ORM\Column(type: Types::DATE_MUTABLE)]
    private ?\DateTimeInterface $date = null;

    #[ORM\Column(length: 255, nullable: true)]
    private ?string $passage = null;

    /**
     * Retrieves the ID of the object.
     *
     * @return int|null The ID of the object, or null if it is not set.
     */
    public function getId(): ?int
    {
        return $this->id;
    }

    /**
     * Sets the ID of the object.
     *
     * @param int $id The ID to set.
     * @return static
     */
    public function setId(int $id): static
    {
        $this->id = $id;

        return $this;
    }

    /**
     * Retrieves the title of the object.
     *
     * @return string|null The title of the object, or null if it is not set.
     */
    public function getTitle(): ?string
    {
        return $this->title;
    }

    /**
     * Sets the title of the object.
     *
     * @param string $title The title to set.
     * @return static
     */
    public function setTitle(string $title): static
    {
        $this->title = $title;

        return $this;
    }

    public function getDate(): ?\DateTimeInterface
    {
        return $this->date;
    }

    public function setDate(\DateTimeInterface $date): static
    {
        $this->date = $date;

        return $this;
    }

    public function getSpeaker(): ?Speaker
    {
        return $this->speaker;
    }

    public function setSpeaker(?Speaker $speaker): static
    {
        $this->speaker = $speaker;

        return $this;
    }

    public function getSeries(): ?Series
    {
        return $this->series;
    }

    public function setSeries(?Series $series): static
    {
        $this->series = $series;

        return $this;
    }

    public function getText(): ?string
    {
        return $this->text;
    }

    public function setText(?string $text): static
    {
        $this->text = $text;

        return $this;
    }

    public function getPassage(): ?string
    {
        return $this->passage;
    }

    public function setPassage(?string $passage): static
    {
        $this->passage = $passage;

        return $this;
    }

    public function jsonSerialize(): array
    {
        return [
            'id' => $this->id,
            'title' => $this->title,
            'speaker' => $this->speaker,
            'series' => $this->series,
            'text' => $this->text,
            'passage' => $this->passage,
            'date' => $this->date->format('Y-m-d'),
        ];
    }
}
